@@ -2,11 +2,12 @@ package App::PAUSE::Comaint;
 
 use strict;
 use 5.008_001;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use App::PAUSE::Comaint::PackageScanner;
 use WWW::Mechanize;
 use ExtUtils::MakeMaker qw(prompt);
+use PAUSE::Permissions;
 
 sub new {
     my($class) = @_;
@@ -26,9 +27,7 @@ sub run {
         die "Usage: comaint Module AUTHOR\n";
     }
 
-    my $scanner = App::PAUSE::Comaint::PackageScanner->new(
-        "$ENV{HOME}/.cpanm/sources/http%www.cpan.org/02packages.details.txt",
-    );
+    my $scanner = App::PAUSE::Comaint::PackageScanner->new('http://cpanmetadb.plackperl.org');
     my @packages = $scanner->find($module);
 
     @packages or die "Couldn't find module '$module' in 02packages\n";
@@ -79,9 +78,11 @@ sub make_comaint {
     }
 
     if (keys %try) {
-        my $msg = "Couldn't find following modules in your maint list:\n";
+        my $perms = PAUSE::Permissions->new(preload => 1);
+        my $msg = "You don't seem to be a primary maintainer of the following modules:\n";
         for my $module (sort keys %try) {
-            $msg .= "  $module\n";
+            my $perm = $perms->module_permissions($module);
+            $msg .= sprintf "  %s (%s)\n", $module, $perm->owner;
         }
         die $msg;
     }
